Class: Dropbox::Sign::AccountResponse
- Inherits:
-
Object
- Object
- Dropbox::Sign::AccountResponse
- Defined in:
- lib/dropbox-sign/models/account_response.rb
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Account.
-
#callback_url ⇒ String?
The URL that Dropbox Sign events will ‘POST` to.
-
#email_address ⇒ String
The email address associated with the Account.
-
#is_locked ⇒ Boolean
Returns ‘true` if the user has been locked out of their account by a team admin.
-
#is_paid_hf ⇒ Boolean
Returns ‘true` if the user has a paid HelloFax account.
-
#is_paid_hs ⇒ Boolean
Returns ‘true` if the user has a paid Dropbox Sign account.
-
#locale ⇒ String?
The locale used in this Account.
- #quotas ⇒ AccountResponseQuotas
-
#role_code ⇒ String?
The membership role for the team.
- #settings ⇒ AccountResponseSettings
-
#team_id ⇒ String?
The id of the team account belongs to.
- #usage ⇒ AccountResponseUsage
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.init(data) ⇒ AccountResponse
Attempt to instantiate and hydrate a new instance of this class.
-
.merged_attributes ⇒ Object
Returns attribute map of this model + parent.
-
.merged_nullable ⇒ Object
Returns list of attributes with nullable: true of this model + parent.
-
.merged_types ⇒ Object
Attribute type mapping of this model + parent.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value, include_nil = true) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash(include_nil = true) ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountResponse
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/dropbox-sign/models/account_response.rb', line 149 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Dropbox::Sign::AccountResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.merged_attributes.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Dropbox::Sign::AccountResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'is_locked') self.is_locked = attributes[:'is_locked'] end if attributes.key?(:'is_paid_hs') self.is_paid_hs = attributes[:'is_paid_hs'] end if attributes.key?(:'is_paid_hf') self.is_paid_hf = attributes[:'is_paid_hf'] end if attributes.key?(:'quotas') self.quotas = attributes[:'quotas'] end if attributes.key?(:'callback_url') self.callback_url = attributes[:'callback_url'] end if attributes.key?(:'role_code') self.role_code = attributes[:'role_code'] end if attributes.key?(:'team_id') self.team_id = attributes[:'team_id'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] end if attributes.key?(:'usage') self.usage = attributes[:'usage'] end if attributes.key?(:'settings') self.settings = attributes[:'settings'] end end |
Instance Attribute Details
#account_id ⇒ String
The ID of the Account
23 24 25 |
# File 'lib/dropbox-sign/models/account_response.rb', line 23 def account_id @account_id end |
#callback_url ⇒ String?
The URL that Dropbox Sign events will ‘POST` to.
46 47 48 |
# File 'lib/dropbox-sign/models/account_response.rb', line 46 def callback_url @callback_url end |
#email_address ⇒ String
The email address associated with the Account.
27 28 29 |
# File 'lib/dropbox-sign/models/account_response.rb', line 27 def email_address @email_address end |
#is_locked ⇒ Boolean
Returns ‘true` if the user has been locked out of their account by a team admin.
31 32 33 |
# File 'lib/dropbox-sign/models/account_response.rb', line 31 def is_locked @is_locked end |
#is_paid_hf ⇒ Boolean
Returns ‘true` if the user has a paid HelloFax account.
39 40 41 |
# File 'lib/dropbox-sign/models/account_response.rb', line 39 def is_paid_hf @is_paid_hf end |
#is_paid_hs ⇒ Boolean
Returns ‘true` if the user has a paid Dropbox Sign account.
35 36 37 |
# File 'lib/dropbox-sign/models/account_response.rb', line 35 def is_paid_hs @is_paid_hs end |
#locale ⇒ String?
The locale used in this Account. Check out the list of [supported locales](/api/reference/constants/#supported-locales) to learn more about the possible values.
58 59 60 |
# File 'lib/dropbox-sign/models/account_response.rb', line 58 def locale @locale end |
#quotas ⇒ AccountResponseQuotas
42 43 44 |
# File 'lib/dropbox-sign/models/account_response.rb', line 42 def quotas @quotas end |
#role_code ⇒ String?
The membership role for the team.
50 51 52 |
# File 'lib/dropbox-sign/models/account_response.rb', line 50 def role_code @role_code end |
#settings ⇒ AccountResponseSettings
64 65 66 |
# File 'lib/dropbox-sign/models/account_response.rb', line 64 def settings @settings end |
#team_id ⇒ String?
The id of the team account belongs to.
54 55 56 |
# File 'lib/dropbox-sign/models/account_response.rb', line 54 def team_id @team_id end |
#usage ⇒ AccountResponseUsage
61 62 63 |
# File 'lib/dropbox-sign/models/account_response.rb', line 61 def usage @usage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/dropbox-sign/models/account_response.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/dropbox-sign/models/account_response.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/dropbox-sign/models/account_response.rb', line 67 def self.attribute_map { :'account_id' => :'account_id', :'email_address' => :'email_address', :'is_locked' => :'is_locked', :'is_paid_hs' => :'is_paid_hs', :'is_paid_hf' => :'is_paid_hf', :'quotas' => :'quotas', :'callback_url' => :'callback_url', :'role_code' => :'role_code', :'team_id' => :'team_id', :'locale' => :'locale', :'usage' => :'usage', :'settings' => :'settings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 |
# File 'lib/dropbox-sign/models/account_response.rb', line 259 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.init(data) ⇒ AccountResponse
Attempt to instantiate and hydrate a new instance of this class
140 141 142 143 144 145 |
# File 'lib/dropbox-sign/models/account_response.rb', line 140 def self.init(data) ApiClient.default.convert_to_type( data, "AccountResponse" ) || AccountResponse.new end |
.merged_attributes ⇒ Object
Returns attribute map of this model + parent
123 124 125 |
# File 'lib/dropbox-sign/models/account_response.rb', line 123 def self.merged_attributes self.attribute_map end |
.merged_nullable ⇒ Object
Returns list of attributes with nullable: true of this model + parent
133 134 135 |
# File 'lib/dropbox-sign/models/account_response.rb', line 133 def self.merged_nullable self.openapi_nullable end |
.merged_types ⇒ Object
Attribute type mapping of this model + parent
128 129 130 |
# File 'lib/dropbox-sign/models/account_response.rb', line 128 def self.merged_types self.openapi_types end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 119 120 |
# File 'lib/dropbox-sign/models/account_response.rb', line 113 def self.openapi_nullable Set.new([ :'callback_url', :'role_code', :'team_id', :'locale', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/dropbox-sign/models/account_response.rb', line 95 def self.openapi_types { :'account_id' => :'String', :'email_address' => :'String', :'is_locked' => :'Boolean', :'is_paid_hs' => :'Boolean', :'is_paid_hf' => :'Boolean', :'quotas' => :'AccountResponseQuotas', :'callback_url' => :'String', :'role_code' => :'String', :'team_id' => :'String', :'locale' => :'String', :'usage' => :'AccountResponseUsage', :'settings' => :'AccountResponseSettings' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/dropbox-sign/models/account_response.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && email_address == o.email_address && is_locked == o.is_locked && is_paid_hs == o.is_paid_hs && is_paid_hf == o.is_paid_hf && quotas == o.quotas && callback_url == o.callback_url && role_code == o.role_code && team_id == o.team_id && locale == o.locale && usage == o.usage && settings == o.settings end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/dropbox-sign/models/account_response.rb', line 289 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model klass = Dropbox::Sign.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value, include_nil = true) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/dropbox-sign/models/account_response.rb', line 360 def _to_hash(value, include_nil = true) if value.is_a?(Array) value.compact.map { |v| _to_hash(v, include_nil) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v, include_nil) } end elsif value.respond_to? :to_hash value.to_hash(include_nil) else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/dropbox-sign/models/account_response.rb', line 266 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attribute_map = self.class.merged_attributes self.class.merged_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/dropbox-sign/models/account_response.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/dropbox-sign/models/account_response.rb', line 252 def hash [account_id, email_address, is_locked, is_paid_hs, is_paid_hf, quotas, callback_url, role_code, team_id, locale, usage, settings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 |
# File 'lib/dropbox-sign/models/account_response.rb', line 214 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
335 336 337 |
# File 'lib/dropbox-sign/models/account_response.rb', line 335 def to_body to_hash end |
#to_hash(include_nil = true) ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/dropbox-sign/models/account_response.rb', line 341 def to_hash(include_nil = true) hash = {} self.class.merged_attributes.each_pair do |attr, param| value = self.send(attr) if value.nil? next unless include_nil is_nullable = self.class.merged_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value, include_nil) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/dropbox-sign/models/account_response.rb', line 329 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 |
# File 'lib/dropbox-sign/models/account_response.rb', line 221 def valid? true end |